@@ -5,30 +5,26 @@ pub mod printer;
 pub mod text_colors;
 
 pub fn get_ascii_colors(
-    ascii_language: Option<&Language>,
-    dominant_language: &Language,
+    language_opt: Option<&Language>,
+    override_language_opt: Option<&Language>,
     ascii_colors: &[u8],
     true_color: bool,
 ) -> Vec<DynColors> {
-    let language = if let Some(ascii_language) = ascii_language {
-        ascii_language
-    } else {
-        dominant_language
+    let language_colors = match language_opt {
+        Some(lang) => override_language_opt.unwrap_or(lang).get_colors(true_color),
+        None => vec![DynColors::Ansi(AnsiColors::White)],
     };
-
-    let mut language_colors: Vec<DynColors> = language.get_colors(true_color);
-
     if ascii_colors.is_empty() {
-        language_colors
-    } else {
-        let mut colors: Vec<DynColors> = ascii_colors.iter().map(num_to_color).collect();
-
-        if language_colors.len() > colors.len() {
-            let mut missing = language_colors.drain(colors.len()..).collect();
-            colors.append(&mut missing);
-        }
-        colors
+        return language_colors;
     }
+
+    let mut colors: Vec<DynColors> = ascii_colors.iter().map(num_to_color).collect();
+
+    if language_colors.len() > colors.len() {
+        colors.extend(language_colors.into_iter().skip(colors.len()));
+    }
+
+    colors
 }
 
 pub fn num_to_color(num: &u8) -> DynColors {
@@ -63,9 +59,33 @@ mod test {
         assert_eq!(num_to_color(&u8::MAX), DynColors::Ansi(AnsiColors::Default));
     }
 
+    #[test]
+    fn get_ascii_colors_no_language_no_custom_language_custom_colors() {
+        let colors = get_ascii_colors(None, None, &[3, 5, 8], false);
+        assert_eq!(colors.len(), 3);
+        assert_eq!(
+            colors,
+            vec![num_to_color(&3), num_to_color(&5), num_to_color(&8)]
+        );
+    }
+
+    #[test]
+    fn get_ascii_colors_no_language_no_custom_language() {
+        let colors = get_ascii_colors(None, None, &[], false);
+        assert_eq!(colors.len(), 1);
+        assert_eq!(colors, vec![DynColors::Ansi(AnsiColors::White)]);
+    }
+
+    #[test]
+    fn get_ascii_colors_no_language_with_custom_language() {
+        let colors = get_ascii_colors(None, Some(&Language::Python), &[], false);
+        assert_eq!(colors.len(), 1);
+        assert_eq!(colors, vec![DynColors::Ansi(AnsiColors::White)]);
+    }
+
     #[test]
     fn get_ascii_colors_no_custom_language_no_custom_colors_no_true_color() {
-        let colors = get_ascii_colors(None.as_ref(), &Language::Rust, &[], false);
+        let colors = get_ascii_colors(Some(&Language::Rust), None, &[], false);
         assert_eq!(colors.len(), 2);
         assert_eq!(
             colors,
@@ -78,7 +98,7 @@ mod test {
 
     #[test]
     fn get_ascii_colors_no_custom_language_no_custom_colors_true_color() {
-        let colors = get_ascii_colors(None, &Language::Rust, &[], true);
+        let colors = get_ascii_colors(Some(&Language::Rust), None, &[], true);
         assert_eq!(colors.len(), 2);
         assert_eq!(
             colors,
@@ -88,14 +108,14 @@ mod test {
 
     #[test]
     fn get_ascii_colors_custom_language_no_custom_colors_no_true_color() {
-        let colors = get_ascii_colors(Some(&Language::Sh), &Language::Rust, &[], false);
+        let colors = get_ascii_colors(Some(&Language::Rust), Some(&Language::Sh), &[], false);
         assert_eq!(colors.len(), 1);
         assert_eq!(colors, vec![DynColors::Ansi(AnsiColors::Green)]);
     }
 
     #[test]
     fn get_ascii_colors_no_custom_language_custom_colors_no_true_color() {
-        let colors = get_ascii_colors(None.as_ref(), &Language::Rust, &[2, 3], false);
+        let colors = get_ascii_colors(Some(&Language::Rust), None, &[2, 3], false);
         assert_eq!(colors.len(), 2);
         assert_eq!(colors, vec![num_to_color(&2), num_to_color(&3)]);
     }
@@ -104,7 +124,7 @@ mod test {
     fn get_ascii_colors_fill_custom_colors_with_language_colors() {
         // When custom ascii colors are not enough for the given language,
         // language colors should be used as default
-        let colors = get_ascii_colors(None, &Language::Go, &[0], false);
+        let colors = get_ascii_colors(Some(&Language::Go), None, &[0], false);
         assert_eq!(colors.len(), 3);
         assert_eq!(
             colors,
